@@ -10,6 +10,7 @@ import sys
 import tarfile
 import logging
 import time
+import platform
 
 import mlflow
 import mlflow.version
@@ -127,11 +128,23 @@ def push_image_to_ecr(image=DEFAULT_IMAGE_NAME):
     # x = ecr_client.get_authorization_token()['authorizationData'][0]
     # docker_login_cmd = "docker login -u AWS -p {token} {url}".format(token=x['authorizationToken']
     #                                                                ,url=x['proxyEndpoint'])
-    docker_login_cmd = "$(aws ecr get-login --no-include-email)"
+    os_command_separator = ";\n"
+    if platform.system() == "Windows":
+        os_command_separator = " && "
+        # In order to execute the outcome of aws ecr get-login
+        # in cmd, we need to save it in a temp file first
+        docker_login_cmd = "aws ecr get-login --no-include-email > docker_login_url_temp.cmd" \
+            "{os_command_separator} call docker_login_url_temp.cmd {os_command_separator}" \
+            "del docker_login_url_temp.cmd".format(os_command_separator=os_command_separator)
+    else:
+        docker_login_cmd = "$(aws ecr get-login --no-include-email)"
     docker_tag_cmd = "docker tag {image} {fullname}".format(
         image=image, fullname=fullname)
     docker_push_cmd = "docker push {}".format(fullname)
-    cmd = ";\n".join([docker_login_cmd, docker_tag_cmd, docker_push_cmd])
+
+    cmd = os_command_separator.join(
+        [docker_login_cmd, docker_tag_cmd, docker_push_cmd])
+    _logger.info("Executing: %s", cmd)
     os.system(cmd)
 
 
@@ -220,18 +233,19 @@ def deploy(app_name, model_uri, execution_role_arn=None, bucket=None,
                        #SageMaker.Client.create_model>`_. For more information, see
                        https://docs.aws.amazon.com/sagemaker/latest/dg/API_VpcConfig.html.
 
-                       Example:
+    .. code-block:: python
+        :caption: Example
 
-                       >>> import mlflow.sagemaker as mfs
-                       >>> vpc_config = {
-                       ...                  'SecurityGroupIds': [
-                       ...                      'sg-123456abc',
-                       ...                  ],
-                       ...                  'Subnets': [
-                       ...                      'subnet-123456abc',
-                       ...                  ]
-                       ...              }
-                       >>> mfs.deploy(..., vpc_config=vpc_config)
+        import mlflow.sagemaker as mfs
+        vpc_config = {
+                        'SecurityGroupIds': [
+                            'sg-123456abc',
+                        ],
+                        'Subnets': [
+                            'subnet-123456abc',
+                        ]
+                     }
+        mfs.deploy(..., vpc_config=vpc_config)
 
     :param flavor: The name of the flavor of the model to use for deployment. Must be either
                    ``None`` or one of mlflow.sagemaker.SUPPORTED_DEPLOYMENT_FLAVORS. If ``None``,
